fn pick_and_save_editor(settings: &mut EditorSettings)Expand description
Prompts for an executable via a native file picker and, if one is chosen, saves it as the
remembered editor (persisted next to the editor executable — see EditorSettings::save) so
future script clicks don’t need to ask again.